// %flair:license{
// This file is part of the Flair framework distributed under the
// CECILL-C License, Version 1.0.
// %flair:license}
//  created:    2016/07/26
//  filename:   ListWidget.cpp
//
//  author:     Thomas Fuhrmann
//              Copyright Heudiasyc UMR UTC/CNRS 7253
//
//  version:    $Id: $
//
//  purpose:    Class displaying a QListWidget on the ground station
//
//
/*********************************************************************/
#include "ListWidget.h"
#include "Layout.h"
#include "LayoutPosition.h"

#include <sstream>
#include <iostream>

using std::string;
using std::ostringstream;

namespace flair {
namespace gui {

ListWidget::ListWidget(const LayoutPosition *position, string name)
    : Widget(position->getLayout(), name, string("ListWidget")) {
  
  selected_item_row = -1;
  selected_item_changed = false;

  size_t count = 0;
  while (1) {
    string item;
    ostringstream item_prop;
    item_prop << "item" << count;
    if(GetPersistentXmlProp(item_prop.str(), item)) {
      SetVolatileXmlProp(item_prop.str(), item);
      items.push_back(item);
    } else {
      break;
    }
    count++;
  }

  SetVolatileXmlProp("row", position->Row());
  SetVolatileXmlProp("col", position->Col());
  delete position;
  SendXml();
}

ListWidget::~ListWidget() { core::Object::ObjectName(); }

void ListWidget::AddItem(string name) {
  items.push_back(name);
  SetVolatileXmlProp("item", name);
  SendXml();
}

void ListWidget::RemoveItem(void) {
  if (selected_item_changed) {
    selected_item_changed = false;
    SetVolatileXmlProp("delete", selected_item_row);
    SendXml();
  }
}

void ListWidget::XmlEvent(void) {
  if (GetPersistentXmlProp("value", selected_item_row)) {
    selected_item_changed = true;
  }
}

} // end namespace gui
} // end namespace flair
